pub enum ExternalReceiptHistoryIoError {
ReadHistory {
path: PathBuf,
source: Error,
},
Parse {
path: PathBuf,
source: ExternalReceiptParseError,
},
}Expand description
I/O errors when reading a receipt history file off disk.
Variants
ReadHistory
The history file could not be opened or read.
Parse
The receipt history text did not parse as repeated v1 receipt records.
Fields

source: ExternalReceiptParseErrorParse failure.