ExternalReceiptParseError

Enum ExternalReceiptParseError 

pub enum ExternalReceiptParseError {
    MissingHeader,
    UnknownFormatHeader {
        observed: String,
    },
    MissingBody,
    MalformedBody {
        reason: String,
    },
    TrailingContent,
    UnknownSink {
        observed: String,
    },
    InvalidHexField {
        field: &'static str,
        value: String,
        expected_len: usize,
    },
    NonMonotonic {
        receipt_index: usize,
        previous_event_count: u64,
        event_count: u64,
    },
}
Parse errors for the v1 external anchor receipt text format.

Variants



MissingHeader

No first line was present.



UnknownFormatHeader

Header was present but was not the supported v1 header.

Fields

observed: String

Header line found in the input.



MissingBody

Header was present but the body line was absent.



MalformedBody

Body did not parse as a valid v1 receipt JSON document.

Fields

reason: String

Human-readable parse failure.



TrailingContent

Extra non-format structure followed the body line.



UnknownSink

Receipt referenced an unknown sink token.

Fields

observed: String

Sink token as parsed from the input.



InvalidHexField

A hex field did not have the expected length or lowercase ASCII shape.

Fields

field: &'static str

Field name in the receipt envelope.

value: String

Field value as parsed from the input.

expected_len: usize

Expected number of hex characters.



NonMonotonic

Receipt history moved backwards in logical event position.

Fields

receipt_index: usize

1-based receipt record index.

previous_event_count: u64

Previous receipt event count.

event_count: u64

Current receipt event count.