pub enum TraceError {
Closed {
trace_id: TraceId,
event_id: EventId,
},
AlreadyClosed {
trace_id: TraceId,
},
}Expand description
Errors raised by TraceAssembler.
Variants
Closed
Attempted to attach an event to a closed (sealed) trace.
Fields
AlreadyClosed
Attempted to close a trace that was already closed.