pub struct ExternalReceiptVerification {
pub path: PathBuf,
pub receipts_path: PathBuf,
pub db_count: u64,
pub receipts_verified: usize,
pub latest_receipt: ExternalReceipt,
pub status: &'static str,
pub trust_root_status: &'static str,
pub trust_root_signed_at: Option<DateTime<Utc>>,
}Expand description
Successful external-receipt verification summary.
Fields
path: PathBufLedger path that was verified against.
receipts_path: PathBufReceipt history path that was verified.
db_count: u64Number of rows observed in the current ledger after scanning the last receipt position.
receipts_verified: usizeNumber of receipts parsed and parser-verified.
latest_receipt: ExternalReceiptThe latest receipt that was verified — has the largest
anchor_event_count.
status: &'static strStable status string. See PARSED_ONLY_VERIFICATION_STATUS.
trust_root_status: &'static strProvenance token for the trusted root that was in force during
verification. Either EMBEDDED_ROOT_STATUS when no operator
cache was supplied or could be loaded, or CACHED_ROOT_STATUS
when a refreshed cache was active.
trust_root_signed_at: Option<DateTime<Utc>>Activation timestamp of the trusted root that was in force.